summaryrefslogtreecommitdiffstats
path: root/kmahjongg/Tileset.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmahjongg/Tileset.h')
-rw-r--r--kmahjongg/Tileset.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kmahjongg/Tileset.h b/kmahjongg/Tileset.h
index 3c09a37c..f728dfb0 100644
--- a/kmahjongg/Tileset.h
+++ b/kmahjongg/Tileset.h
@@ -10,14 +10,14 @@ class Tileset {
~Tileset();
bool loadTileset(const TQString &filesetPath, const bool isPreview = false);
- QRgb *createTile(short x, short y, QRgb *dst, TQImage &src , QRgb *face);
- QRgb *copyTileImage(short tileX, short tileY, QRgb *to, TQImage &from);
+ TQRgb *createTile(short x, short y, TQRgb *dst, TQImage &src , TQRgb *face);
+ TQRgb *copyTileImage(short tileX, short tileY, TQRgb *to, TQImage &from);
void setScaled(bool sc) {isScaled = sc; divisor = (sc) ? 2 : 1;}
- QRgb *tile(short tnum);
- QRgb *selectedTile(short tnum);
+ TQRgb *tile(short tnum);
+ TQRgb *selectedTile(short tnum);
short width() {return w/divisor;}
short height() {return h/divisor;}
short shadowSize() {return ss/divisor;}
@@ -57,18 +57,18 @@ class Tileset {
protected:
enum { maxTiles=45 };
- void createPixmap(QRgb *src, TQPixmap &dest, bool scale, bool shadow);
+ void createPixmap(TQRgb *src, TQPixmap &dest, bool scale, bool shadow);
private:
- TQBitmap maskBits; // xbm mask for the tile
- TQBitmap maskBitsMini; // xbm mask for the tile
- QRgb* tiles; // Buffer containing all tiles (unselected glyphs)
- QRgb* selectedTiles; // Buffer containing all tiles (selected glyphs)
+ TQBitmap tqmaskBits; // xbm tqmask for the tile
+ TQBitmap tqmaskBitsMini; // xbm tqmask for the tile
+ TQRgb* tiles; // Buffer containing all tiles (unselected glyphs)
+ TQRgb* selectedTiles; // Buffer containing all tiles (selected glyphs)
// in version 0.5 we have moved ftom using images and calculating
- // masks etc, to using pixmaps and letting the blt do the hard work,
+ // tqmasks etc, to using pixmaps and letting the blt do the hard work,
// in hardware.
TQPixmap selectedPix[maxTiles]; // selected tiles
TQPixmap unselectedPix[maxTiles]; // unselected tiles
@@ -83,10 +83,10 @@ class Tileset {
- QRgb* selectedFace; // The tile background face for a selected tile
- QRgb* unselectedFace;// The tile background face for an unselected tile
+ TQRgb* selectedFace; // The tile background face for a selected tile
+ TQRgb* unselectedFace;// The tile background face for an unselected tile
- QRgb tr; // transparenct color for tile bg
+ TQRgb tr; // transparenct color for tile bg
short ss; // left/bottom shadow width
short bs; // width of the border around a tile